fn module_search_scope(db: &RootDatabase, module: Module) -> Vec<SearchScope>Expand description
Build a search scope spanning the given module but none of its submodules.
fn module_search_scope(db: &RootDatabase, module: Module) -> Vec<SearchScope>Build a search scope spanning the given module but none of its submodules.